==========
Exceptions
==========
.. currentmodule:: polars.exceptions

.. autosummary::
    :toctree: api/
    :nosignatures:
    
    ArrowError
    ComputeError
    NoDataError
    NotFoundError
    SchemaError
    ShapeError
    DuplicateError
    PanicException
